==> cherokee-0.4.16.tar.gz: cherokee-0.4.16/src/handler.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <stdlib.h>
#include <string.h>

#include "handler.h"
#include "connection.h"

ret_t
cherokee_handler_init_base (cherokee_handler_t *hdl, void *conn)
{
	/* Init the base class
	 */
	cherokee_module_init_base (hdl);

	/* Pure virtual methods
	 */
	hdl->step        = NULL;
	hdl->add_headers = NULL;

	/* Parent reference
	 */
	hdl->connection = conn;
	
	return ret_ok;
}



/* 	Virtual method hidding layer
 */
ret_t
cherokee_handler_free (cherokee_handler_t *hdl)
{
	if (MODULE(hdl)->free) {
		return MODULE(hdl)->free (hdl); 
	}
	
	return ret_error;
}


inline ret_t
cherokee_handler_init (cherokee_handler_t *hdl)
{
	handler_func_init_t init_func;

	init_func = (handler_func_init_t) MODULE(hdl)->init;

	if (init_func) {
		return init_func(hdl); 
	}
	
	return ret_error;
}


inline ret_t
cherokee_handler_step (cherokee_handler_t *hdl, cherokee_buffer_t *buffer)
{
	if (hdl->step) {
		return hdl->step (hdl, buffer);
	}
	
	return ret_error;
}


inline ret_t
cherokee_handler_add_headers (cherokee_handler_t *hdl, cherokee_buffer_t *buffer)
{
	if (hdl->add_headers) {
		return hdl->add_headers (hdl, buffer); 
	}

	return ret_error;
}

==> cherokee-0.4.17.1.tar.gz: cherokee-0.4.17/src/handler.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include "handler.h"

#include <stdlib.h>
#include <string.h>

#include "connection.h"


ret_t
cherokee_handler_init_base (cherokee_handler_t *hdl, void *conn)
{
	/* Init the base class
	 */
	cherokee_module_init_base (MODULE(hdl));

	/* Pure virtual methods
	 */
	hdl->step        = NULL;
	hdl->add_headers = NULL;

	/* Parent reference
	 */
	hdl->connection = conn;
	return ret_ok;
}


ret_t 
cherokee_handler_free_base (cherokee_handler_t *hdl)
{
	free (hdl);
	return ret_ok;
}


/* 	Virtual method hidding layer
 */
ret_t
cherokee_handler_free (cherokee_handler_t *hdl)
{
	ret_t ret;

	if (MODULE(hdl)->free == NULL) {
		return ret_error;
	}

	/* Call the destructor virtual method
	 */
	ret = MODULE(hdl)->free (hdl); 
	if (ret < ret_ok) return ret;
	
	/* Free the handler memory
	 */
	free (hdl);
	return ret_ok;
}


inline ret_t
cherokee_handler_init (cherokee_handler_t *hdl)
{
	handler_func_init_t init_func;

	init_func = (handler_func_init_t) MODULE(hdl)->init;

	if (init_func) {
		return init_func(hdl); 
	}
	
	return ret_error;
}


inline ret_t
cherokee_handler_step (cherokee_handler_t *hdl, cherokee_buffer_t *buffer)
{
	if (hdl->step) {
		return hdl->step (hdl, buffer);
	}
	
	return ret_error;
}


inline ret_t
cherokee_handler_add_headers (cherokee_handler_t *hdl, cherokee_buffer_t *buffer)
{
	if (hdl->add_headers) {
		return hdl->add_headers (hdl, buffer); 
	}

	return ret_error;
}
